### Name: nested.coxph
### Title: Estimate Cox model hazard ratios for covariates with missing
###   data
### Aliases: nested.coxph
### Keywords: models

### ** Examples

## Simple analysis of zinc and esophageal cancer data:
## We sampled zinc (variable zncent) on a fraction of the subjects, with
## sampling fractions depending on cancer status and baseline histology.
## We observed the confounding variables on almost all subjects.
data(zinc)
coxmod <- nested.coxph(coxformula="Surv(futime01,ec01==1)~
          sex+agepill+smoke+drink+mildysp+moddysp+sevdysp+anyhist+zncent",
          samplingmod="ec01*basehist",data=zinc)
summary(coxmod)

# This is the output:
#  Call:
#  coxph(formula = as.formula(coxformula), data = data, weights = 1/p.i.h.a.t., 
#      na.action = na.omit, control = coxphcontrol, method = "breslow", 
#      x = T)

#    n=123 (308 observations deleted due to missing)
#                               coef exp(coef) se(coef)       z       p
#  sexMale                    0.2953     1.344   0.5558  0.5313 6.0e-01
#  agepill                    0.0539     1.055   0.0275  1.9612 5.0e-02
#  smokeEver                  0.0145     1.015   0.5870  0.0248 9.8e-01
#  drinkEver                 -0.8548     0.425   0.5896 -1.4497 1.5e-01
#  mildyspMild Dysplasia      0.9023     2.465   0.3937  2.2921 2.2e-02
#  moddyspModerate Dysplasia  1.3309     3.784   0.4212  3.1600 1.6e-03
#  sevdyspSevere Dysplasia    2.1334     8.444   0.4615  4.6224 3.8e-06
#  anyhistFamily History      0.0904     1.095   0.3896  0.2321 8.2e-01
#  zncent                    -0.2498     0.779   0.1351 -1.8487 6.4e-02

#                            exp(coef) exp(-coef) lower .95 upper .95
#  sexMale                       1.344      0.744     0.452      3.99
#  agepill                       1.055      0.948     1.000      1.11
#  smokeEver                     1.015      0.986     0.321      3.21
#  drinkEver                     0.425      2.351     0.134      1.35
#  mildyspMild Dysplasia         2.465      0.406     1.140      5.33
#  moddyspModerate Dysplasia     3.784      0.264     1.658      8.64
#  sevdyspSevere Dysplasia       8.444      0.118     3.417     20.86
#  anyhistFamily History         1.095      0.914     0.510      2.35
#  zncent                        0.779      1.284     0.598      1.02

#  Rsquare= NA   (max possible= NA )
#  Likelihood ratio test= NA  on 9 df,   p=NA
#  Wald test            = 66.5  on 9 df,   p=7.32e-11
#  Score (logrank) test = NA  on 9 df,   p=NA



